@@ -8,8 +8,7 @@
 
 #include "treemodel.h"
 
-#include <QApplication>
-#include <QDesktopWidget>
+#include <QGuiApplication>
 #include <QScreen>
 
 using namespace KDevelop;
