@@ -15,15 +15,15 @@
 
 #include <serialization/indexedstring.h>
 
-#include <grantlee/context.h>
+#include <KArchive>
+#include <KTextTemplate/Context>
 
 #include <QDir>
 #include <QFile>
+#include <QRegularExpression>
 #include <QUrl>
 
-#include <KArchive>
-
-using namespace Grantlee;
+using namespace KTextTemplate;
 
 class NoEscapeStream
     : public OutputStream
@@ -62,7 +62,7 @@ class TemplateRendererPrivate
 {
 public:
     Engine* engine;
-    Grantlee::Context context;
+    KTextTemplate::Context context;
     TemplateRenderer::EmptyLinesPolicy emptyLinesPolicy;
     QString errorString;
 };
@@ -115,10 +115,9 @@ QString TemplateRenderer::render(const QString& content, const QString& name)
     NoEscapeStream stream(&textStream);
     t->render(&stream, &d->context);
 
-    if (t->error() != Grantlee::NoError) {
+    if (t->error() != KTextTemplate::NoError) {
         d->errorString = t->errorString();
-    } else
-    {
+    } else {
         d->errorString.clear();
     }
 
@@ -243,7 +242,7 @@ DocumentChangeSet TemplateRenderer::renderFileTemplate(const SourceFileTemplate&
     DocumentChangeSet changes;
     const QDir baseDir(baseUrl.path());
 
-    QRegExp nonAlphaNumeric(QStringLiteral("\\W"));
+    static const QRegularExpression nonAlphaNumeric(QStringLiteral("\\W"));
     for (QHash<QString, QUrl>::const_iterator it = fileUrls.constBegin(); it != fileUrls.constEnd(); ++it) {
         QString cleanName = it.key().toLower();
         cleanName.replace(nonAlphaNumeric, QStringLiteral("_"));
