@@ -284,7 +284,7 @@ public:
 
     QVector<DUContext*> importers() const override;
 
-    ///Returns all currently loade importers
+    ///Returns all currently loaded importers
     virtual QList<DUContext*> loadedImporters() const;
 
     CursorInRevision importPosition(const DUContext* target) const override;
@@ -378,7 +378,7 @@ protected:
 KDEVPLATFORMLANGUAGE_EXPORT QVector<RangeInRevision> allUses(TopDUContext* context, Declaration* declaration,
                                                              bool noEmptyRanges = false);
 
-inline uint qHash(const ReferencedTopDUContext& ctx)
+inline size_t qHash(const ReferencedTopDUContext& ctx)
 {
     return ctx.hash();
 }
