@@ -77,21 +77,13 @@ QColor colorForDocument(const QUrl& url, const QPalette& palette, const QColor&
 
 }
 
-void MainWindow::applyMainWindowSettings(const KConfigGroup& config)
-{
-    Q_D(MainWindow);
-
-    if(!d->changingActiveView())
-        KXmlGuiWindow::applyMainWindowSettings(config);
-}
-
 void MainWindow::createGUI(KParts::Part* part)
 {
     Sublime::MainWindow::setWindowTitleHandling(false);
     Sublime::MainWindow::createGUI(part);
 }
 
-void MainWindow::initializeCorners()
+void MainWindow::loadCornerSettings()
 {
     const KConfigGroup cg = KSharedConfig::openConfig()->group(QStringLiteral("UiSettings"));
     const int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
@@ -118,7 +110,6 @@ MainWindow::MainWindow( Sublime::Controller *parent, Qt::WindowFlags flags )
         this, QDBusConnection::ExportScriptableSlots );
 
     setAcceptDrops( true );
-    initializeCorners();
 
     setObjectName( QStringLiteral("MainWindow") );
     d_ptr = new MainWindowPrivate(this);
@@ -160,6 +151,13 @@ void MainWindow::split(Qt::Orientation orientation)
     d->split(orientation);
 }
 
+void MainWindow::loadUiPreferences()
+{
+    loadCornerSettings();
+    updateAllTabColors();
+    Sublime::MainWindow::loadUiPreferences();
+}
+
 void MainWindow::ensureVisible()
 {
     if (isMinimized()) {
@@ -256,12 +254,25 @@ void MainWindow::dropEvent( QDropEvent* ev )
 
 void MainWindow::loadSettings()
 {
-    qCDebug(SHELL) << "Loading Settings";
-    initializeCorners();
+    Q_D(const MainWindow);
 
-    updateAllTabColors();
+    if (!d->isGuiSetUp()) {
+        // UiController() invokes this->loadSettings() before UiController::initialize() invokes this->initialize().
+        // this->initialize() invokes KXmlGuiWindow::setupGUI(), which resizes the window to its default size.
+        // Sublime::MainWindow::loadSettings() calls KXmlGuiWindow::applyMainWindowSettings(), which applies the size
+        // stored in the main window config *once*. If the size stored in config is applied before the default resizing,
+        // the window always ends up having the default size. Prevent this by returning early if the GUI is not set up
+        // (not initialized) yet. The settings are still always loaded when UiController::loadAllAreas() is invoked
+        // after this->initialize().
+        return;
+    }
+
+    qCDebug(SHELL) << "Loading Settings";
 
     Sublime::MainWindow::loadSettings();
+    // Sublime::MainWindow::loadSettings() invokes QMainWindow::restoreState(), which restores corner
+    // settings. Override the corner settings to make sure they match KDevelop's custom corner options.
+    loadCornerSettings();
 }
 
 void MainWindow::configureShortcuts()
@@ -339,7 +350,19 @@ void MainWindow::initialize()
     Q_D(MainWindow);
 
     KStandardAction::keyBindings(this, SLOT(configureShortcuts()), actionCollection());
-    setupGUI(ToolBar | Save);
+
+    // Do not pass the Save option to setupGUI(), because main window settings are loaded from and saved to
+    // different config groups depending on the current area. So KMainWindow::autoSaveGroup() would have to
+    // be changed accordingly each time another area is switched to. Also Sublime::MainWindow::saveSettings()
+    // and Sublime::MainWindow::loadSettings() do more than just call saveMainWindowSettings() and
+    // applyMainWindowSettings() respectively. applyMainWindowSettings() is virtual and can be overridden, but
+    // there is no way to customize behavior of the non-virtual function KMainWindow::saveMainWindowSettings().
+    // Auto-saving also requires recovering from a possible last auto-save while in Concentration Mode - perhaps
+    // force-exit Concentration Mode even if it is off at the end of Sublime::MainWindow::loadSettings().
+    // On KDevelop exit, UiController::cleanup() calls Sublime::MainWindow::saveSettings() for each main window.
+    // Therefore, auto-saving main window settings is useful only in case KDevelop crashes. Auto-saving correctly
+    // might be possible, but perhaps not worth the likely significant implementation complexity increase.
+    setupGUI(QSize{870, 650}, ToolBar);
     createGUI(nullptr);
 
     Core::self()->partController()->addManagedTopLevelWidget(this);
@@ -404,16 +427,12 @@ void MainWindow::cleanup()
 {
 }
 
-void MainWindow::setVisible( bool visible )
-{
-    KXmlGuiWindow::setVisible( visible );
-    emit finishedLoading();
-}
-
 bool MainWindow::queryClose()
 {
-    if (!Core::self()->documentControllerInternal()->saveAllDocumentsForWindow(this, IDocument::Default))
+    if (!Core::self()->documentControllerInternal()->saveAllDocumentsForWindow(
+            this, IDocumentController::SaveSelectionMode::LetUserSelect)) {
         return false;
+    }
 
     return Sublime::MainWindow::queryClose();
 }
@@ -584,4 +603,12 @@ void MainWindow::newTabRequested()
     d->fileNew();
 }
 
+void MainWindow::saveNewToolbarConfig()
+{
+    // Applying a toolbar config removes actions added via KXMLGUIClient::plugActionList().
+    Sublime::MainWindow::saveNewToolbarConfig();
+    // So plug the available_sessions actions again as the documentation for KEditToolBar recommends.
+    Core::self()->sessionController()->updateXmlGuiActionList();
+}
+
 #include "moc_mainwindow.cpp"
