@@ -12,7 +12,6 @@
 
 #include <QObject>
 #include <QPointer>
-#include <QWidget>
 #include <QMap>
 #include <KXMLGUIClient>
 
@@ -20,6 +19,7 @@
 
 class KActionCollection;
 class QMenu;
+class QWidget;
 
 namespace Sublime {
 class View;
@@ -50,7 +50,11 @@ public:
     explicit MainWindowPrivate(MainWindow *mainWindow);
     ~MainWindowPrivate() override;
 
-    QPointer<QWidget> centralPlugin;
+    /**
+     * @return whether setupGui() has been called
+     */
+    [[nodiscard]] bool isGuiSetUp() const;
+
     QMetaObject::Connection activeDocumentReadWriteConnection;
 
     void setupActions();
@@ -92,17 +96,10 @@ public Q_SLOTS:
     void gotoNextSplit();
     void gotoPreviousSplit();
 
-    void newToolbarConfig();
-
     void settingsDialog();
 
     void quitAll();
 
-//    void fixToolbar();
-
-    ///Returns true if we're currently changing the active view through changeActiveView()
-    bool changingActiveView() const ;
-
     void configureNotifications();
     void showLoadedPlugins();
 
@@ -128,11 +125,10 @@ private:
     MainWindow* const m_mainWindow;
     StatusBar* m_statusBar;
     QWidget* lastXMLGUIClientView;
-    QPointer<QWidget> m_workingSetCornerWidget;
 
     QMap<IPlugin*, KXMLGUIClient*> m_pluginCustomClients;
 
-    bool m_changingActiveView;
+    bool m_isGuiSetUp = false;
     /// the view of the tab that got it's context menu connected
     Sublime::View* m_tabView;
     QPair<Sublime::View*, QPointer<NavigationToolTip> > m_tabTooltip;
