@@ -7,13 +7,11 @@
 */
 
 #include "idealdockwidget.h"
-#include "mainwindow.h"
 #include "area.h"
 #include "document.h"
+#include "idealcontroller.h"
 #include "view.h"
 
-#include <util/scopeddialog.h>
-
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -22,13 +20,15 @@
 #include <QAbstractButton>
 #include <QDialog>
 #include <QDialogButtonBox>
+#include <QMainWindow>
+#include <QMenu>
 #include <QToolBar>
 #include <QVBoxLayout>
 #include <QActionGroup>
 
 using namespace Sublime;
 
-IdealDockWidget::IdealDockWidget(IdealController *controller, Sublime::MainWindow *parent)
+IdealDockWidget::IdealDockWidget(IdealController* controller, QMainWindow* parent)
     : QDockWidget(parent),
       m_area(nullptr),
       m_view(nullptr),
@@ -74,6 +74,17 @@ Qt::DockWidgetArea IdealDockWidget::dockWidgetArea() const
 void IdealDockWidget::setDockWidgetArea(Qt::DockWidgetArea dockingArea)
 { m_docking_area = dockingArea; }
 
+void IdealDockWidget::activate()
+{
+    // The focus can be given to a widget only if it or one of its parents is the active window.
+    // A floating dock widget is a top-level window, so activate it before focusing. If this dock widget
+    // is not floating, activate its main window in case another floating dock widget is the active window.
+    activateWindow();
+    // Also raise this dock widget to place it in front of other floating dock widgets.
+    raise();
+    setFocus(Qt::ShortcutFocusReason);
+}
+
 void IdealDockWidget::slotRemove()
 {
     m_area->removeToolView(m_view);
@@ -84,7 +95,7 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
     QWidget* senderWidget = qobject_cast<QWidget*>(sender());
     Q_ASSERT(senderWidget);
 
-    KDevelop::ScopedDialog<QMenu> menu(senderWidget);
+    auto* const menu = new QMenu(senderWidget);
     menu->addSection(windowIcon(), m_view->document()->title());
 
     const QList<QAction*> viewActions = m_view->contextMenuActions();
@@ -120,14 +131,18 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
         positionMenu->addAction(action);
         action->setCheckable(true);
     }
+
+    QAction* currentPositionAction = nullptr;
     if (isFloating()) {
-        detach->setChecked(true);
+        currentPositionAction = detach;
     } else if (m_docking_area == Qt::BottomDockWidgetArea)
-        bottom->setChecked(true);
+        currentPositionAction = bottom;
     else if (m_docking_area == Qt::LeftDockWidgetArea)
-        left->setChecked(true);
+        currentPositionAction = left;
     else if (m_docking_area == Qt::RightDockWidgetArea)
-        right->setChecked(true);
+        currentPositionAction = right;
+    Q_ASSERT_X(currentPositionAction, Q_FUNC_INFO, "unsupported dock widget area");
+    currentPositionAction->setChecked(true);
     /// end position menu
 
     menu->addSeparator();
@@ -138,6 +153,7 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
     menu->addSeparator();
     QAction* remove = menu->addAction(QIcon::fromTheme(QStringLiteral("dialog-close")), i18nc("@action:inmenu", "Remove Tool View"));
 
+    menu->setAttribute(Qt::WA_DeleteOnClose);
     QAction* triggered = menu->exec(senderWidget->mapToGlobal(point));
 
     if (triggered)
@@ -172,32 +188,53 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
             delete dialog;
 
             return;
+        } else if (triggered == currentPositionAction) {
+            // the current position is reselected
+            if (isVisible()) {
+                activate();
+            }
+            return; // nothing more to do
         } else if ( triggered == detach ) {
             setFloating(true);
-            m_area->raiseToolView(m_view);
             return;
         }
 
+        Qt::DockWidgetArea dockingArea;
+        if (triggered == left)
+            dockingArea = Qt::LeftDockWidgetArea;
+        else if (triggered == bottom)
+            dockingArea = Qt::BottomDockWidgetArea;
+        else if (triggered == right)
+            dockingArea = Qt::RightDockWidgetArea;
+        else
+            return;
+
+        // Attach this dock widget to dockingArea without changing its visibility.
+
+        const auto isVisible = this->isVisible();
+
+        auto* const mainWindow = qobject_cast<QMainWindow*>(parentWidget());
+        Q_ASSERT(mainWindow);
+
+        // The addDockWidget() and removeDockWidget() calls in IdealController::showDockWidget() mean that an
+        // invisible dock widget is not associated with any dock widget area as far as QMainWindow is concerned.
+        // Therefore, if this dock widget is invisible, the attaching via setFloating(false) below
+        // has effect only if addDockWidget() is called first, even if dockingArea equals m_docking_area.
+
+        if (dockingArea != m_docking_area || !isVisible) {
+            // The two-argument overload of QMainWindow::addDockWidget() removes the dock widget from
+            // the main window layout if it is already there, i.e. properly moves to the new area.
+            mainWindow->addDockWidget(dockingArea, this);
+        }
+
         if (isFloating()) {
             setFloating(false);
         }
 
-        Sublime::Position pos;
-        if (triggered == left)
-            pos = Sublime::Left;
-        else if (triggered == bottom)
-            pos = Sublime::Bottom;
-        else if (triggered == right)
-            pos = Sublime::Right;
-        else
-            return;
-
-        Area *area = m_area;
-        View *view = m_view;
-        /* This call will delete *this, so we no longer
-           can access member variables. */
-        m_area->moveToolView(m_view, pos);
-        area->raiseToolView(view);
+        if (!isVisible) {
+            // Restore the invariant that an invisible dock widget is absent from the main window layout.
+            mainWindow->removeDockWidget(this);
+        }
     }
 }
 
