@@ -9,9 +9,7 @@
 #define KDEVPLATFORM_IREPOSITORYVERSIONCONTROL_H
 
 #include <QObject>
-
-class QString;
-class QStringList;
+#include <QStringList>
 
 namespace KDevelop
 {
