@@ -163,7 +163,7 @@ void MIDebugger::processLine(const QByteArray& line)
         // sometimes produces invalid messages that can be safely ignored.
         qCDebug(DEBUGGERCOMMON) << "Invalid MI message:" << line;
         // We don't consider the current command done.
-        // So, if a command results in unparseable reply,
+        // So, if a command results in unparsable reply,
         // we'll just wait for the "right" reply, which might
         // never come.  However, marking the command as
         // done in this case is even more risky.
@@ -214,9 +214,7 @@ void MIDebugger::processLine(const QByteArray& line)
                                         << m_currentCmd->queueTime()
                                         << m_currentCmd->gdbProcessingTime();
                 m_currentCmd->invokeHandler(result);
-            }
-            else if (result.reason == QLatin1String("error"))
-            {
+            } else if (result.isReasonError()) {
                 qCDebug(DEBUGGERCOMMON) << "Handling error";
                 m_currentCmd->markAsCompleted();
                 qCDebug(DEBUGGERCOMMON) << "Command error, times"
@@ -295,6 +293,10 @@ void MIDebugger::processLine(const QByteArray& line)
                     m_currentCmd->newOutput(s.message);
             } else {
                 emit debuggerInternalOutput(s.message);
+
+                if (m_currentCmd) {
+                    m_currentCmd->newLogStreamOutput(s.message);
+                }
             }
 
             emit streamRecord(s);
