@@ -74,7 +74,7 @@ protected:
      */
     QString toHtmlEscaped(QString text);
 
-    QString colorify(QString text, const QColor &color);
+    void colorify(QString& text, const QColor& color);
 
     /**
      * Makes 'l' no longer than 'max_size' by
@@ -86,21 +86,31 @@ protected:
     void focusInEvent(QFocusEvent *e) override;
 
 protected Q_SLOTS:
-    void showContextMenu(const QPoint &pos);
     void toggleRepeat(bool checked);
     void toggleShowInternalCommands(bool checked);
     void flushPending();
     void clear();
 
-    void handleSessionChanged(KDevelop::IDebugSession *session);
-    void handleDebuggerStateChange(DBGStateFlags oldStatus, DBGStateFlags newStatus);
     void receivedInternalCommandStdout(const QString &line);
     void receivedUserCommandStdout(const QString &line);
     void receivedStdout(const QString &line, bool internal);
     void receivedStderr(const QString &line);
 
     void trySendCommand(QString cmd);
+
 private:
+    void textViewContextMenuRequested(const QPoint& viewportPosition);
+
+    void currentSessionChanged(KDevelop::IDebugSession* iSession, KDevelop::IDebugSession* iPreviousSession);
+    /**
+     * Call this function when the debugger state of the current session changes to update the UI accordingly.
+     */
+    void debuggerStateChanged(DBGStateFlags newState);
+    /**
+     * Call this function when the debugger is not running to update the UI accordingly.
+     */
+    void handleDebuggerNotRunning();
+
     QAction *m_actRepeat;
     QAction *m_actInterrupt;
     QAction *m_actShowInternal;
