@@ -10,7 +10,6 @@
 
 #include "debugsession.h"
 
-#include "debuggerplugin.h"
 #include "gdb.h"
 #include "gdbbreakpointcontroller.h"
 #include "gdbframestackmodel.h"
@@ -27,8 +26,6 @@
 #include <interfaces/icore.h>
 #include <interfaces/idebugcontroller.h>
 #include <interfaces/ilaunchconfiguration.h>
-#include <interfaces/iuicontroller.h>
-#include <sublime/message.h>
 #include <util/environmentprofilelist.h>
 
 #include <KConfigGroup>
@@ -47,20 +44,14 @@ using namespace KDevMI::GDB;
 using namespace KDevMI::MI;
 using namespace KDevelop;
 
-DebugSession::DebugSession(CppDebuggerPlugin *plugin)
-    : MIDebugSession(plugin)
+DebugSession::DebugSession()
 {
     m_breakpointController = new BreakpointController(this);
     m_variableController = new VariableController(this);
     m_frameStackModel = new GdbFrameStackModel(this);
-
-    if (m_plugin) m_plugin->setupToolViews();
 }
 
-DebugSession::~DebugSession()
-{
-    if (m_plugin) m_plugin->unloadToolViews();
-}
+DebugSession::~DebugSession() = default;
 
 void DebugSession::setAutoDisableASLR(bool enable)
 {
@@ -239,9 +230,7 @@ bool DebugSession::execInferior(KDevelop::ILaunchConfiguration *cfg, IExecutePlu
             CmdMaybeStartsRunning));
     } else {
         // normal local debugging
-        addCommand(MI::FileExecAndSymbols, KShell::quoteArg(executable),
-                   this, &DebugSession::handleFileExecAndSymbols,
-                   CmdHandlesError);
+        addFileExecAndSymbolsCommand(KShell::quoteArg(executable));
         raiseEvent(connected_to_program);
 
         addCommand(std::make_unique<SentinelCommand>(
@@ -254,18 +243,9 @@ bool DebugSession::execInferior(KDevelop::ILaunchConfiguration *cfg, IExecutePlu
     return true;
 }
 
-bool DebugSession::loadCoreFile(KDevelop::ILaunchConfiguration*,
-                                const QString& debugee, const QString& corefile)
+void DebugSession::loadCoreFile(const QString& coreFile)
 {
-    addCommand(MI::FileExecAndSymbols, debugee,
-               this, &DebugSession::handleFileExecAndSymbols,
-               CmdHandlesError);
-    raiseEvent(connected_to_program);
-
-    addCommand(NonMI, QLatin1String("core ") + corefile,
-               this, &DebugSession::handleCoreFile,
-               CmdHandlesError);
-    return true;
+    addCommand(NonMI, QLatin1String("core ") + coreFile, this, &DebugSession::handleCoreFile, CmdHandlesError);
 }
 
 void DebugSession::handleVersion(const QStringList& s)
@@ -299,37 +279,16 @@ void DebugSession::handleVersion(const QStringList& s)
     const QString messageText = i18n("<b>You need gdb 7.0.0 or higher.</b><br />"
         "You are using: %1",
         detectedVersion);
-    auto* message = new Sublime::Message(messageText, Sublime::Message::Error);
-    ICore::self()->uiController()->postMessage(message);
-    stopDebugger();
-}
-
-void DebugSession::handleFileExecAndSymbols(const ResultRecord& r)
-{
-    if (r.reason == QLatin1String("error")) {
-        const QString messageText =
-            i18n("<b>Could not start debugger:</b><br />")+
-                 r[QStringLiteral("msg")].literal();
-        auto* message = new Sublime::Message(messageText, Sublime::Message::Error);
-        ICore::self()->uiController()->postMessage(message);
-        stopDebugger();
-    }
+    stopDebuggerOnError(messageText);
 }
 
 void DebugSession::handleCoreFile(const ResultRecord& r)
 {
-    if (r.reason != QLatin1String("error")) {
-        setDebuggerStateOn(s_programExited | s_core);
-    } else {
-        const QString messageText =
-            i18n("<b>Failed to load core file</b>"
-                 "<p>Debugger reported the following error:"
-                 "<p><tt>%1",
-                 r[QStringLiteral("msg")].literal());
-        auto* message = new Sublime::Message(messageText, Sublime::Message::Error);
-        ICore::self()->uiController()->postMessage(message);
-        stopDebugger();
+    if (r.isReasonError()) {
+        failedToLoadCoreFile(r.errorMessage());
+        return;
     }
+    coreFileLoaded();
 }
 
 #include "moc_debugsession.cpp"
