@@ -23,8 +23,8 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(NinjaBuilderFactory, "kdevninja.json", registerPlugin<NinjaBuilder>(); )
 
-NinjaBuilder::NinjaBuilder(QObject* parent, const QVariantList&)
-    : KDevelop::IPlugin(QStringLiteral("kdevninja"), parent)
+NinjaBuilder::NinjaBuilder(QObject* parent, const KPluginMetaData& metaData, const QVariantList&)
+    : KDevelop::IPlugin(QStringLiteral("kdevninja"), parent, metaData)
 {
     if (NinjaJob::ninjaExecutable().isEmpty()) {
         setErrorDescription(i18n("Unable to find ninja executable. Is it installed on the system?"));
