@@ -1,15 +1,8 @@
-/***************************************************************************
-   Copyright 2006-2009 David Nolden <david.nolden.kdevelop@art-master.de>
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2009 David Nolden <david.nolden.kdevelop@art-master.de>
 
-/***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KDEVPLATFORM_PLUGIN_PATCHREVIEWTOOLVIEW_H
 #define KDEVPLATFORM_PLUGIN_PATCHREVIEWTOOLVIEW_H
@@ -103,7 +96,7 @@ public Q_SLOTS:
     void documentActivated( KDevelop::IDocument* );
     void customContextMenuRequested(const QPoint& p);
     void testJobResult(KJob* job);
-    void testJobPercent(KJob* job, ulong percent);
+    void testJobPercent(KJob* job, unsigned long percent);
 };
 
 #endif // KDEVPLATFORM_PLUGIN_PATCHREVIEWTOOLVIEW_H
